# Mkdocs Page to PDF

An Mkdocs plugin to generate a PDF file for each MkDocs page.

## How to use

Install the package with pip:

```shell
pip install mkdocs-page-pdf
```

Enable the plugin in your mkdocs.yml:

```yaml
plugins:
  # - ...
    - pdf-export # should be last
```


